import sys
import time
import lepcpy as le


def main():
    device = ''

    # parse argument
    if len(sys.argv) == 1:
        pass
    elif len(sys.argv) == 2:
        device = sys.argv[1]
    else:
        print(f'usage: {sys.argv[0]} <serial number>')
        return 0

    # connect to analyzer
    if not le.connect(device):
        print('connect failed')
        return 1

    print(f'connect ({device if device != "" else "Auto"})')

    # set trigger action
    factor = le.LE_TRIGGERFACTOR()
    factor.eFactor = chr(le.LE_TRGFACTOR_CHARACTER)
    sdMaskBytes = [le.LE_LMBYTE() for _ in range(8)]
    rdMaskBytes = [le.LE_LMBYTE() for _ in range(8)]
    for mb in sdMaskBytes:
        mb.bMask = 0
        mb.bPattern = 255
    for i, mb in enumerate(rdMaskBytes):
        mb.bMask = 0
        if i == 0:
            mb.bPattern = 0
        else:
            mb.bPattern = 255
    factor.mbSd = sdMaskBytes
    factor.mbRd = rdMaskBytes
    factor.mbW = [le.LE_LMBYTE() for _ in range(3)]

    actionTimer = le.LE_TRIGGERACTION()
    actionTimer.eAction = chr(le.LE_TRGACTION_TIMER)
    actionTimer.eTimer = chr(le.LE_TIMER_0)
    actionTimer.eTimerAction = chr(le.LE_TRGTIMERACTION_START)

    actionCounter = le.LE_TRIGGERACTION()
    actionCounter.eAction = chr(le.LE_TRGACTION_COUNTER)
    actionCounter.eCounter = chr(le.LE_COUNTER_0)
    actionCounter.eCounterAction = chr(le.LE_TRGCOUNTERACTION_INCREMENT)

    le.setTrigger(0, factor, actionTimer)
    le.setTrigger(1, factor, actionCounter)

    # test capture (10 sec)
    if not le.startOnline():
        print('startOnline failed')
        return 1

    for i in range(10):
        time.sleep(1)
        print(f'  capturing... {i + 1:02}/10')

    if not le.stop():
        print('stop failed')
        return 1

    timer = le.getTimer(0)
    counter = le.getCounter(0)

    print(f'Timer0  : {timer}')
    print(f'Counter0: {counter}')

    le.disconnect()


if __name__ == '__main__':
    main()
