import tkinter as tk
import lepcpy as le
import sys

KEY_NUM = [
    ('0', le.LE_REMOTE_KEY_0),
    ('1', le.LE_REMOTE_KEY_1),
    ('2', le.LE_REMOTE_KEY_2),
    ('3', le.LE_REMOTE_KEY_3),
    ('4', le.LE_REMOTE_KEY_4),
    ('5', le.LE_REMOTE_KEY_5),
    ('6', le.LE_REMOTE_KEY_6),
    ('7', le.LE_REMOTE_KEY_7),
    ('8', le.LE_REMOTE_KEY_8),
    ('9', le.LE_REMOTE_KEY_9),
    ('A', le.LE_REMOTE_KEY_A),
    ('B', le.LE_REMOTE_KEY_B),
    ('C', le.LE_REMOTE_KEY_C),
    ('D', le.LE_REMOTE_KEY_D),
    ('E', le.LE_REMOTE_KEY_E),
    ('F', le.LE_REMOTE_KEY_F),
]

KEY_SPECIAL = [
    ('ESC', le.LE_REMOTE_KEY_ESC),
    ('DEL', le.LE_REMOTE_KEY_DELETE),
    ('X', le.LE_REMOTE_KEY_DONTCARE),
]

KEY_MEASURE = [
    ('MENU', le.LE_REMOTE_KEY_MENU),
    ('STOP', le.LE_REMOTE_KEY_STOP),
    ('RUN', le.LE_REMOTE_KEY_RUN),
]

KEY_DIR = [
    ('^', le.LE_REMOTE_KEY_UP),
    ('<', le.LE_REMOTE_KEY_LEFT),
    ('ENTER', le.LE_REMOTE_KEY_ENTER),
    ('>', le.LE_REMOTE_KEY_RIGHT),
    ('v', le.LE_REMOTE_KEY_DOWN),
]


def getOnPressKeyFunc(shiftOn, keyCode):
    def onPressKey(event):
        le.emulationKey(keyCode | (0x80 if shiftOn.get() else 0x00))
    return onPressKey


def main():
    device = ''

    if len(sys.argv) == 1:
        pass
    elif len(sys.argv) == 2:
        device = sys.argv[1]
    else:
        print(f'usage: {sys.argv[0]} <serial number>')
        return 0

    # connect to analyzer
    if not le.connect(device):
        print('connect failed')
        return 1

    # tk
    root = tk.Tk()
    root.title(u'Key')
    shiftOn = tk.BooleanVar()

    # layout number keys
    numRow = 3
    numCol = 0
    for i, (text, keyCode) in enumerate(KEY_NUM):
        button = tk.Button(text=text, width=4, height=2)
        button.bind('<Button-1>', getOnPressKeyFunc(shiftOn, keyCode))
        button.grid(row=numRow, column=numCol)

        numCol += 1
        if numCol % 4 == 0:
            numCol = 0
            numRow -= 1

    # layout special keys
    for i, (text, keyCode) in enumerate(KEY_SPECIAL):
        button = tk.Button(text=text, width=4, height=2)
        button.bind('<Button-1>', getOnPressKeyFunc(shiftOn, keyCode))
        button.grid(row=i, column=5)
    # shift
    check = tk.Checkbutton(text='Shift', variable=shiftOn)
    check.grid(row=3, column=5)

    # layout measure keys
    for i, (text, keyCode) in enumerate(KEY_MEASURE):
        button = tk.Button(text=text, width=4, height=2)
        button.bind('<Button-1>', getOnPressKeyFunc(shiftOn, keyCode))
        button.grid(row=0, column=6 + i)

    # layout direction keys
    # up
    text, keyCode = KEY_DIR[0]
    button = tk.Button(text=text, width=4, height=2)
    button.bind('<Button-1>', getOnPressKeyFunc(shiftOn, keyCode))
    button.grid(row=1, column=7)
    # left
    text, keyCode = KEY_DIR[1]
    button = tk.Button(text=text, width=4, height=2)
    button.bind('<Button-1>', getOnPressKeyFunc(shiftOn, keyCode))
    button.grid(row=2, column=6)
    # enter
    text, keyCode = KEY_DIR[2]
    button = tk.Button(text=text, width=4, height=2)
    button.bind('<Button-1>', getOnPressKeyFunc(shiftOn, keyCode))
    button.grid(row=2, column=7)
    # right
    text, keyCode = KEY_DIR[3]
    button = tk.Button(text=text, width=4, height=2)
    button.bind('<Button-1>', getOnPressKeyFunc(shiftOn, keyCode))
    button.grid(row=2, column=8)
    # down
    text, keyCode = KEY_DIR[4]
    button = tk.Button(text=text, width=4, height=2)
    button.bind('<Button-1>', getOnPressKeyFunc(shiftOn, keyCode))
    button.grid(row=3, column=7)

    root.mainloop()


if __name__ == '__main__':
    try:
        main()
    finally:
        le.disconnect()
